==> nui_core-0.0.56.tar.gz: lib/ui/component/tab/nui_tab_child_view.dart <==
import 'dart:developer';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';
import 'package:visibility_detector/visibility_detector.dart';

abstract class NUITabInstance{
//  int getSelectedPosition();
//  int getTabPosition();
  Widget getInBackgroundContent();
  Widget getOnScreenContent();
}

class NUITabChildStatefulWidget extends StatefulWidget implements NUITabInstance{
  NUITabChildStatefulWidget({this.backgroundContent, @required this.onScreenContent, Key key}): super(key:key);
  final Widget backgroundContent;
  final Widget onScreenContent;

  @override
  Widget getOnScreenContent() => onScreenContent;

  @override
  Widget getInBackgroundContent() => backgroundContent;

  @override
  NUITabChildState<NUITabChildStatefulWidget> createState() => NUITabChildState<NUITabChildStatefulWidget>();
}

class NUITabChildState<T extends NUITabChildStatefulWidget> extends State<T> implements NUITabInstance{
//  int _currentPosition = 0;
  bool _hasLoaded = false;
  String id = randomUUID();

//  void updateCurrentPosition(int position){
//    this._currentPosition = position;
//    log("Tab Child -> updating position to $position of item : ${getTabPosition()}, has loaded : $_hasLoaded");
//    if(!_hasLoaded && isVisible()){
//      setState(() {
//        _hasLoaded = true;
//      });
//    }
//  }

  @override
  Widget getInBackgroundContent() => widget.backgroundContent;

  @override
  Widget getOnScreenContent() => widget.onScreenContent;

  @override
  Widget build(BuildContext context) {
    if(getInBackgroundContent() == null) _hasLoaded = true;

    if(_hasLoaded != true){
      return VisibilityDetector(
          key: Key(id),
          child: getInBackgroundContent() != null ? getInBackgroundContent() : getOnScreenContent(),
          onVisibilityChanged: (info){
            logNUI("NUITabChildView", "Visible fraction : ${info.visibleFraction}");
            final visibility = info.visibleFraction;
            if(visibility >= 1 && _hasLoaded != true){
              _hasLoaded = true;
              setState(() {

              });
            }
          });
    }
    return getOnScreenContent();
  }
}

==> nui_core-0.0.127.tar.gz: lib/ui/component/tab/nui_tab_child_view.dart <==
import 'dart:developer';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';
import 'package:visibility_detector/visibility_detector.dart';

abstract class NUITabInstance{
//  int getSelectedPosition();
//  int getTabPosition();
  Widget getInBackgroundContent();
  Widget getOnScreenContent();
}

class NUITabChildStatefulWidget extends StatefulWidget implements NUITabInstance{
  NUITabChildStatefulWidget({this.backgroundContent, @required this.onScreenContent, Key key}): super(key:key);
  final Widget backgroundContent;
  final Widget onScreenContent;

  @override
  Widget getOnScreenContent() => onScreenContent;

  @override
  Widget getInBackgroundContent() => backgroundContent;

  @override
  NUITabChildState<NUITabChildStatefulWidget> createState() => NUITabChildState<NUITabChildStatefulWidget>();
}

class NUITabChildState<T extends NUITabChildStatefulWidget> extends State<T> implements NUITabInstance{
//  int _currentPosition = 0;
  bool _hasLoaded = false;
  String id = randomUUID();

//  void updateCurrentPosition(int position){
//    this._currentPosition = position;
//    log("Tab Child -> updating position to $position of item : ${getTabPosition()}, has loaded : $_hasLoaded");
//    if(!_hasLoaded && isVisible()){
//      setState(() {
//        _hasLoaded = true;
//      });
//    }
//  }

  @override
  Widget getInBackgroundContent() => widget.backgroundContent;

  @override
  Widget getOnScreenContent() => widget.onScreenContent;

  @override
  Widget build(BuildContext context) {
    if(getInBackgroundContent() == null) _hasLoaded = true;

    if(_hasLoaded != true && getInBackgroundContent() != null){
      return VisibilityDetector(
          key: Key(id),
          child: getInBackgroundContent(),
          onVisibilityChanged: (info){
            logNUI("NUITabChildView", "Visible fraction : ${info.visibleFraction}");
            final visibility = info.visibleFraction;
            if(visibility >= 1 && _hasLoaded != true){
              _hasLoaded = true;
              setState(() {

              });
            }
          });
    }
    return getOnScreenContent();
  }
}
